@@ -6,10 +6,6 @@
 
 '''A simple Twitter client made with pyqt4 : QListView'''
 
-import sip
-sip.setapi('QString', 2)
-sip.setapi('QVariant', 2)
-
 SCREENNAMEROLE = 20
 REPLYTOSCREENNAMEROLE = 21
 REPLYTEXTROLE = 22
@@ -41,7 +37,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
     '''Delegate to do custom draw of the items'''
 
     memoized_size = {}
-    memoized_width = {}
 
     def __init__(self, parent):
         '''Initialization'''
@@ -57,7 +52,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         self.text_color = QColor('#FFFFFF')
         self.separator_color = QColor('#000000')
         self.fsize = 1.0
-        
         self.fm = None
         self.minifm = None
 
@@ -68,6 +62,13 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         self.retweet_icon = QPixmap(os.path.join(os.path.dirname(__file__),'icons','retweet.png'))
         self.geoloc_icon = QPixmap(os.path.join(os.path.dirname(__file__),'icons','geoloc.png'))
 
+    def doZoomRefresh(self):
+        self.memoized_size.clear()
+        self.fm = None
+        self.minifm = None
+        self.normFont = None
+        self.miniFont = None
+
     def sizeHint(self, option, index):
         '''Custom size calculation of our items'''
 
@@ -112,7 +113,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
                         | int(Qt.TextWordWrap),
                     reply_text,
                     ).height() + 5
-                    
+
             height += self.minifm.boundingRect(
                 0,
                 0,
@@ -154,15 +155,13 @@ class DefaultCustomDelegate(QStyledItemDelegate):
 
 
         #Query data
-        model = index.model()
         tweet = index.data(Qt.DisplayRole)
-        is_me = index.data(ISMEROLE)
         screenname = index.data(SCREENNAMEROLE)
         retweet_of = index.data(RETWEETOFROLE)
         timestamp = index.data(role=TIMESTAMPROLE)
         reply_name = index.data(role=REPLYTOSCREENNAMEROLE)
         reply_text = index.data(role=REPLYTEXTROLE)
-        
+
         painter.save()
 
         # Draw alternate ?
@@ -180,7 +179,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         if icon != None:
             painter.drawPixmap(x1 + 10, y1 + 10, 50, 50, icon)
 
-        # Draw screenname        
+        # Draw screenname
         painter.setFont(self.miniFont)
         painter.setPen(self.user_color)
         nrect = painter.drawText(option.rect.adjusted(70, 5, -4, -9),
@@ -203,7 +202,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
             painter.drawText(option.rect.adjusted(110+nrect.width(), 5, -4, -9),
                                  int(Qt.AlignTop) | int(Qt.AlignLeft),
                                  retweet_of.user.screen_name)
-            
         # Draw tweet
         painter.setFont(self.normFont)
         painter.setPen(self.text_color)
@@ -212,7 +210,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
                                  int(Qt.AlignTop)
                                  | int(Qt.AlignLeft)
                                  | int(Qt.TextWordWrap), tweet)
-        
         # Draw Timeline
         painter.setFont(self.miniFont)
         painter.setPen(self.time_color)
@@ -255,7 +252,7 @@ class WhiteCustomDelegate(DefaultCustomDelegate):
         self.text_color = QColor('#000000')
         self.separator_color = QColor('#000000')
         self.fsize = 1.0
-        
+
 class MiniDefaultCustomDelegate(DefaultCustomDelegate):
 
     '''Delegate to do custom draw of the items'''
@@ -318,21 +315,25 @@ class KhweetsView(QListView):
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
 
     def keyPressEvent(self, event):
-        if event.key() not in (Qt.Key_Up, Qt.Key_Down, Qt.CTRL + Qt.Key_Down, Qt.CTRL + Qt.Key_Up, Qt.CTRL + Qt.Key_Left, Qt.CTRL + Qt.Key_Right, Qt.CTRL + Qt.Key_C):
+        if (event.key() in (Qt.Key_Up, Qt.Key_Down, Qt.Key_Control)):
+            QListView.keyPressEvent(self, event)
+        else:
             self.parent().switch_tb_edit()
             self.parent().tb_text.setFocus()
             self.parent().tb_text.keyPressEvent(event)
-        else:
-            QListView.keyPressEvent(self, event)
 
     def do_zoom_in(self):
+        print 'do zoom in called'
         self.custom_delegate.fsize = self.custom_delegate.fsize + 0.1
-        self.update()
+        self.custom_delegate.doZoomRefresh()
+        self.parent().resize(-1,-1)
 
     def do_zoom_out(self):
+        print 'do zoom out called'
         self.custom_delegate.fsize = self.custom_delegate.fsize - 0.1
-        self.update()
-        
+        self.custom_delegate.doZoomRefresh()
+        self.parent().resize(-1,-1)
+
     def refreshCustomDelegate(self):
         settings = QSettings("Khertan Software", "Khweeteur")
         theme = settings.value('theme')
